Name:           tuxcmd
Version:        0.6.70
Release:        18%{?dist}
Summary:        Tux Commander: file manager with 2 panels side by side using GTK2

Group:          Applications/File
License:        GPLv2+

# FreePascal restrictions
ExcludeArch:    s390 s390x

URL:            http://tuxcmd.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
Source1:        http://downloads.sourceforge.net/%{name}/%{name}-modules-%{version}.tar.bz2

BuildRequires: fpc >= 2.6.2-4%{?dist}
BuildRequires: glib2-devel
BuildRequires: gtk2-devel
BuildRequires: desktop-file-utils
BuildRequires: libgcc
BuildRequires: ZipArchive-devel
BuildRequires: zlib-devel
BuildRequires: bzip2-devel


# turn smartlinking off, not needed anymore with fpc-2.2.2-2
Patch4: tuxcmd-disable-smartlinking.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=755320
# Bug 755320 - tuxcmd can not be built due to new libarchive and new glib
Patch5: tuxcmd-module-libarchive_libarchive-3.0.0a.patch
Patch6: tuxcmd-module-gvfs_include-glib.patch

# ARM linking compatibility
Patch9: tuxcmd-arm-gcc_s.so-linking.patch

# Remove bundled zip deps (#1103599)
Patch10: tuxcmd-0.6.70-remove-bundled-zip-deps.patch

%description
Tux Commander is open-source file manager with 2 panels side by side written
for GTK2. The main goal of this project is to create powerful user-friendly
file manager for Linux. Functionality can be further extended by pluggable
VFS (virtual file system) modules.


%package modules
Summary:        Modules for Tux Commander file manager
Group:          Applications/File
Requires: %{name} = %{version}-%{release}
BuildRequires: libarchive-devel >= 2.5.5
BuildRequires: bzip2-devel


%description modules
The tuxcmd-modules package contains extra VFS (virtual file system) modules
extending Tux Commander's functionality:
 * libarchive plugin - handles TAR/GZ/BZ2 archives
 * ZIP plugin


%package gvfs
Summary:        GVFS module for Tux Commander file manager
Group:          Applications/File
Requires: %{name} = %{version}-%{release}
Requires: gvfs


%description gvfs
This package contains networking GVFS module for Tux Commander file manager.


%prep
%setup -q -b 1
%patch4 -p1 -b .disable-smartlinking
# dirty hack to workaround weird linking issue
ln -s %{_libdir}/libgcc_s.so.1 libgcc_s.so
%patch9 -p1 -b .arm-gcc_s.so-linking

pushd ../%{name}-modules-%{version}
%patch5 -p1 -b .libarchive3
%patch6 -p1 -b .glib-include
%patch10 -p1 -b .bundled-zip
popd

# Removing bundled libs
rm -rf ../tuxcmd-modules-0.6.70/zip/ZipArchive
rm -rf ../tuxcmd-modules-0.6.70/libarchive/libarchive-2.5.5


%build
make final_debug

# build modules
cd ../%{name}-modules-%{version}
make CC="gcc %{optflags}" CPP="g++ %{optflags}" shared


%install
make install DESTDIR=$RPM_BUILD_ROOT/usr
desktop-file-install --delete-original  \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
    $RPM_BUILD_ROOT%{_datadir}/applications/tuxcmd.desktop

find $RPM_BUILD_ROOT -name COPYING -exec rm -f {} ';'
find $RPM_BUILD_ROOT -name README -exec rm -f {} ';'

# install modules
cd ../%{name}-modules-%{version}
make install DESTDIR=$RPM_BUILD_ROOT/usr
mkdir -p doc/libarchive
cp -pr libarchive/{COPYING,README} doc/libarchive
mkdir -p doc/zip
cp -pr zip/{COPYING,README} doc/zip


%post
update-desktop-database %{_datadir}/applications &> /dev/null
touch --no-create %{_datadir}/icons/hicolor
if [ -x /usr/bin/gtk-update-icon-cache ]; then
  gtk-update-icon-cache -q %{_datadir}/icons/hicolor
fi


%postun
update-desktop-database %{_datadir}/applications &> /dev/null
touch --no-create %{_datadir}/icons/hicolor
if [ -x /usr/bin/gtk-update-icon-cache ]; then
  gtk-update-icon-cache -q %{_datadir}/icons/hicolor
fi


%files
%doc COPYING README
%dir %{_libdir}/tuxcmd
%{_bindir}/tuxcmd
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg


%files modules
%doc ../%{name}-modules-%{version}/doc/libarchive
%doc ../%{name}-modules-%{version}/doc/zip
%{_libdir}/tuxcmd/libarchive_plugin.so
%{_libdir}/tuxcmd/libzip_plugin.so


%files gvfs
%doc ../%{name}-modules-%{version}/gvfs/README
%doc ../%{name}-modules-%{version}/gvfs/COPYING
%{_libdir}/tuxcmd/libgvfs_plugin.so


%changelog
* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.70-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Apr 09 2015 Jaromir Capik <jcapik@redhat.com> - 0.6.70-16
- Removing bundled libarchive

* Thu Apr 09 2015 Jaromir Capik <jcapik@redhat.com> - 0.6.70-15
- Removing bundled ZipArchive (#1103599)
- Cleaning the spec

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Sep 27 2013 Tomas Bzatek <tbzatek@redhat.com> - 0.6.70-12
- Fix ARM linking issues (#992824)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 17 2013 Tomas Bzatek <tbzatek@redhat.com> - 0.6.70-9
- Rebuilt for new libarchive

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-7
- Rebuilt for c++ ABI breakage

* Tue Jan 31 2012 Tomas Bzatek <tbzatek@redhat.com> - 0.6.70-6
- Fix GCC 4.7 compatibility

* Wed Jan 25 2012 Tomas Bzatek <tbzatek@redhat.com> - 0.6.70-5
- Rebuilt for new libarchive

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Nov 24 2011 Tomas Bzatek <tbzatek@redhat.com> - 0.6.70-3
- Fix build against libarchive 3
- Fix glib includes

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.70-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Nov 19 2009 Tomas Bzatek <tbzatek@redhat.com> 0.6.70-1
- Update to v0.6.70

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.62-git20090409.2.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Apr 10 2009 Tomas Bzatek <tbzatek@redhat.com> 0.6.62-git20090409.2
- Fix vfs modules detection on 64bit archs
- Remove unnecessary Requires (#473992)

* Thu Apr  9 2009 Tomas Bzatek <tbzatek@redhat.com> 0.6.62-git20090409.1
- Rebase to latest git
- Fix unowned directories (#473992)

* Sat Feb 28 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 0.6.50-7
- fix compile with gcc44, use optflags

* Fri Feb 27 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 0.6.50-6
- fix ExclusiveArch

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.50-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Oct 21 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.50-4
- Turn smartlinking off, not needed with fpc-2.2.2-2 anymore
- Enable debuginfo generation on x86_64 again

* Mon Oct 13 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.50-3
- Connection Manager: Fix restoring last used item

* Tue Oct  7 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.50-2
- Hide '0' and NULL mount points
- GVFS plugin: supply proper user/pass for anonymous FTP login

* Fri Oct  3 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.50-1
- Update to v0.6.50

* Mon Aug 25 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.36-5
- Use supplied libc unit (ripped out from original FPC sources)
- Do not generate debug info on x86_64 (buggy compiler)

* Mon Aug 25 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.36-4
- Rebuild against FPC 2.2.2 (fixes threading issues)
- Do not generate executable stack (fixes SELinux issues)

* Mon Jun  9 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.36-3
- Add ZIP module

* Fri Jun  6 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.36-2
- Add modules (gnome-vfs2, libarchive)

* Mon Jun  2 2008 Tomas Bzatek <tbzatek@redhat.com> 0.6.36-1
- Initial packaging
